
# Slot: batch_size




URI: [https://w3id.org/neat/classifierFitParams__batch_size](https://w3id.org/neat/classifierFitParams__batch_size)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [ClassifierFitParams](ClassifierFitParams.md)
